@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2017  Martin Lund
+ * Copyright (c) 2016-2022  Martin Lund
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -59,7 +59,7 @@ struct option_t option =
     false,      // Default no hexadecimal print
     false,      // Default no interactive mode
     false,      // Default no run script
-    "",         // Default script filename
+    "",         // Default SCPI filename
     "",         // Default lua script filename
     "",         // Default screenshot plugin name
     false,      // Default no list
@@ -78,11 +78,11 @@ void print_help(char *argv[])
     printf("  -h, --help                           Display help\n");
     printf("\n");
     printf("Commands:\n");
-    printf("  discover [<options>]                 Search for LXI devices\n");
+    printf("  discover [<options>]                 Search for devices\n");
     printf("  scpi [<options>] <scpi-command>      Send SCPI command\n");
     printf("  screenshot [<options>] [<filename>]  Capture screenshot\n");
     printf("  benchmark [<options>]                Benchmark\n");
-    printf("  run [<options>] <filename>           Run Lua script\n");
+    printf("  run <filename>                       Run Lua script\n");
     printf("\n");
     printf("Discover options:\n");
     printf("  -t, --timeout <seconds>              Timeout (default: Normal: %d, mDNS: %d)\n", TIMEOUT_DISCOVER, TIMEOUT_DISCOVER_MDNS);
@@ -94,7 +94,7 @@ void print_help(char *argv[])
     printf("  -t, --timeout <seconds>              Timeout (default: %d)\n", option.timeout);
     printf("  -x, --hex                            Print response in hexadecimal\n");
     printf("  -i, --interactive                    Enter interactive mode\n");
-    printf("  -s, --script <filename>              Run script file\n");
+    printf("  -f, --file <filename>                Run SCPI commands from file\n");
     printf("  -r, --raw                            Use raw/TCP\n");
     printf("\n");
     printf("Screenshot options:\n");
@@ -110,14 +110,11 @@ void print_help(char *argv[])
     printf("  -c, --count <count>                  Number of requests (default: %d)\n", option.count);
     printf("  -r, --raw                            Use raw/TCP\n");
     printf("\n");
-    printf("Run options:\n");
-    printf("  -t, --timeout <seconds>              Timeout (default: %d)\n", option.timeout);
-    printf("\n");
 }
 
 void print_version(void)
 {
-    printf("lxi v%s\n", VERSION);
+    printf("lxi v%s\n", PACKAGE_VERSION);
 }
 
 void parse_options(int argc, char *argv[])
@@ -193,7 +190,7 @@ void parse_options(int argc, char *argv[])
             {"timeout",        required_argument, 0, 't'},
             {"hex",            no_argument,       0, 'x'},
             {"interactive",    no_argument,       0, 'i'},
-            {"script",         required_argument, 0, 's'},
+            {"file",           required_argument, 0, 'f'},
             {"raw",            no_argument,       0, 'r'},
             {0,                0,                 0,  0 }
         };
@@ -201,12 +198,12 @@ void parse_options(int argc, char *argv[])
         do
         {
             /* Parse scpi options */
-            c = getopt_long(argc, argv, "a:p:t:xis:r", long_options, &option_index);
+            c = getopt_long(argc, argv, "a:p:t:xif:r", long_options, &option_index);
 
             switch (c)
             {
                 case 'a':
-                    strncpy(option.ip, optarg, 500);
+                    strncpy(option.ip, optarg, 499);
                     break;
 
                 case 'p':
@@ -225,9 +222,9 @@ void parse_options(int argc, char *argv[])
                     option.interactive = true;
                     break;
 
-                case 's':
+                case 'f':
                     option.run_script = true;
-                    option.script_filename = optarg;
+                    option.scpi_filename = optarg;
                     break;
 
                 case 'r':
@@ -262,7 +259,7 @@ void parse_options(int argc, char *argv[])
             switch (c)
             {
                 case 'a':
-                    strncpy(option.ip, optarg, 500);
+                    strncpy(option.ip, optarg, 499);
                     break;
 
                 case 't':
@@ -303,7 +300,7 @@ void parse_options(int argc, char *argv[])
             switch (c)
             {
                 case 'a':
-                    strncpy(option.ip, optarg, 500);
+                    strncpy(option.ip, optarg, 499);
                     break;
 
                 case 'p':
@@ -393,7 +390,7 @@ void parse_options(int argc, char *argv[])
     if (option.command == SCPI)
     {
         if (optind != argc)
-            strncpy(option.scpi_command, argv[optind++], 500);
+            strncpy(option.scpi_command, argv[optind++], 499);
 
         if (strlen(option.ip) == 0)
         {
@@ -401,7 +398,7 @@ void parse_options(int argc, char *argv[])
             exit(EXIT_FAILURE);
         }
 
-        if ((strlen(option.scpi_command) == 0) && (option.interactive == false))
+        if ((strlen(option.scpi_command) == 0) && (option.interactive == false) && (option.run_script == false))
         {
             error_printf("No SCPI command specified\n");
             exit(EXIT_FAILURE);
@@ -410,12 +407,12 @@ void parse_options(int argc, char *argv[])
 
     if ((option.command == SCREENSHOT) && (optind != argc))
     {
-        strncpy(option.screenshot_filename, argv[optind++], 1000);
+        strncpy(option.screenshot_filename, argv[optind++], 999);
     }
 
     if ((option.command == RUN) && (optind != argc))
     {
-        strncpy(option.lua_script_filename, argv[optind++], 1000);
+        strncpy(option.lua_script_filename, argv[optind++], 999);
     }
 
     /* Print any unknown arguments */
